%bcond_with	bootstrap
%bcond_with	tests

%global pypi_name wheel
%global python_wheel_name %{pypi_name}-%{version}-py3-none-any.whl

Name:           python-%{pypi_name}
Version:        0.43.0
Release:        %mkrel 3
Summary:        A built-package format for Python
Group:          Development/Python
License:        MIT
URL:            https://pypi.org/project/wheel
Source0:        %{pypi_source}
# This is used in bootstrap mode where we manually install the wheel and
# entrypoints
Source1:        wheel-entrypoint
BuildArch:      noarch

BuildRequires:  python3-devel
# python3 bootstrap: this is rebuilt before the final build of python3, which
# adds the dependency on python3-rpm-generators, so we require it manually
BuildRequires:  python3-rpm-generators

# Needed to manually build and unpack the wheel
%if %{with bootstrap}
BuildRequires:  python3-flit-core
BuildRequires:  unzip
%endif

%if %{with tests}
BuildRequires:  python3-pytest
BuildRequires:  python3-setuptools
# several tests compile extensions
# those tests are skipped if gcc is not found
BuildRequires:  gcc
%endif

%description
A built-package format for Python.

A wheel is a ZIP-format archive with a specially formatted filename and the
.whl extension. It is designed to contain all the files for a PEP 376
compatible install in a way that is very close to the on-disk format.

%package -n     python3-%{pypi_name}
Summary:        A built-package format for Python
%if %{with bootstrap}
Provides:       python%{python3_pkgversion}dist(wheel) = %{version}
Provides:       python%{python3_version}dist(wheel) = %{version}
%endif

%description -n python3-%{pypi_name}
A built-package format for Python.

A wheel is a ZIP-format archive with a specially formatted filename and the
.whl extension. It is designed to contain all the files for a PEP 376
compatible install in a way that is very close to the on-disk format.

%package wheel
Summary:	The Python wheel module packaged as a wheel
Group:		Development/Python

%description wheel
A Python wheel of wheel to use with virtualenv.


%prep
%autosetup -n %{pypi_name}-%{version} -p1


%if %{without bootstrap}
%generate_buildrequires
%pyproject_buildrequires
%endif


%build
%if %{with bootstrap}
%global _pyproject_wheeldir dist
%python3 -m flit_core.wheel
%else
%pyproject_wheel
%endif


%install
# pip is not available when bootstrapping, so we need to unpack the wheel and
# create the entrypoints manually.
%if %{with bootstrap}
mkdir -p %{buildroot}%{python3_sitelib}
unzip %{_pyproject_wheeldir}/%{python_wheel_name} \
    -d %{buildroot}%{python3_sitelib} -x wheel-%{version}.dist-info/RECORD
install -Dpm 0755 %{SOURCE1} %{buildroot}%{_bindir}/wheel
%py3_shebang_fix %{buildroot}%{_bindir}/wheel
%else
%pyproject_install
%endif

mv %{buildroot}%{_bindir}/%{pypi_name}{,-%{python3_version}}

ln -s %{pypi_name}-%{python3_version} %{buildroot}%{_bindir}/%{pypi_name}-3
ln -s %{pypi_name}-3 %{buildroot}%{_bindir}/%{pypi_name}


mkdir -p %{buildroot}%{python_wheel_dir}
install -p %{_pyproject_wheeldir}/%{python_wheel_name} -t %{buildroot}%{python_wheel_dir}


%check
# Smoke test
%{py3_test_envvars} wheel-%{python3_version} version
%py3_check_import wheel

%if %{with tests}
%pytest -v --ignore build
%endif

%files -n python3-%{pypi_name}
%license LICENSE.txt
%doc README.rst
%{_bindir}/%{pypi_name}-%{python3_version}
%{_bindir}/%{pypi_name}
%{_bindir}/%{pypi_name}-3
%{python3_sitelib}/%{pypi_name}*/

%files wheel
%license LICENSE.txt
# we own the dir for simplicity
%dir %{python_wheel_dir}/
%{python_wheel_dir}/%{python_wheel_name}


%changelog
* Thu Feb 20 2025 wally <wally> 0.43.0-3.mga10
+ Revision: 2150156
- non-bootstrap build for python3.13

* Thu Feb 20 2025 wally <wally> 0.43.0-2.mga10
+ Revision: 2150137
- bootstrap build for python3.13

* Tue Jul 02 2024 papoteur <papoteur> 0.43.0-1.mga10
+ Revision: 2079003
- new version 0.43.0

* Wed Dec 20 2023 wally <wally> 0.42.0-1.mga10
+ Revision: 2020389
- new version 0.42.0
- sync with Fedora where appropriate

* Thu Dec 07 2023 wally <wally> 0.41.3-5.mga10
+ Revision: 2014723
- true non-bootstrap build for py3.12 update

* Thu Dec 07 2023 wally <wally> 0.41.3-4.mga10
+ Revision: 2014711
- non-bootstrap build for py3.12 update
- non-bootstrap build for py3.12 update

* Thu Dec 07 2023 wally <wally> 0.41.3-2.mga10
+ Revision: 2014564
- bootstrap build for py3.12 update

* Sat Nov 25 2023 wally <wally> 0.41.3-1.mga10
+ Revision: 2009565
- new version 0.41.3

* Sat Jul 01 2023 daviddavid <daviddavid> 0.37.1-2.mga9
+ Revision: 1963345
- add ubuntu patch to fix CVE-2022-40898 (mga#31420)

* Mon Oct 03 2022 neoclust <neoclust> 0.37.1-1.mga9
+ Revision: 1894212
- New version 0.37.1

* Tue Mar 29 2022 umeabot <umeabot> 0.36.2-6.mga9
+ Revision: 1831344
- Mageia 9 Mass Rebuild

* Sat Feb 05 2022 wally <wally> 0.36.2-5.mga9
+ Revision: 1771771
- disable bootstrap build

* Sat Feb 05 2022 wally <wally> 0.36.2-4.mga9
+ Revision: 1771616
- bootstrap build for python 3.10

* Sun Mar 14 2021 wally <wally> 0.36.2-3.mga9
+ Revision: 1702612
- disable bootstrap

* Sun Mar 14 2021 wally <wally> 0.36.2-2.mga9
+ Revision: 1702516
- bootstrap build for new python 3.9

* Tue Mar 02 2021 guillomovitch <guillomovitch> 0.36.2-1.mga9
+ Revision: 1696413
- new version 0.36.2

* Sat Nov 07 2020 wally <wally> 0.35.1-2.mga8
+ Revision: 1643163
- fix binary symlinks

* Wed Sep 16 2020 guillomovitch <guillomovitch> 0.35.1-1.mga8
+ Revision: 1626948
- new version 0.35.1

* Thu Feb 20 2020 umeabot <umeabot> 0.33.6-2.mga8
+ Revision: 1546102
- Mageia 8 Mass Rebuild

* Fri Jan 31 2020 daviddavid <daviddavid> 0.33.6-1.mga8
+ Revision: 1485930
- new version: 0.33.6

* Tue Sep 03 2019 wally <wally> 0.33.1-3.mga8
+ Revision: 1436769
- non-bootstrap build for python3.8

* Tue Sep 03 2019 wally <wally> 0.33.1-2.mga8
+ Revision: 1436764
- bootstrap build for python3.8
- drop python2 support

* Wed Apr 17 2019 wally <wally> 0.33.1-1.mga7
+ Revision: 1392184
- new version 0.33.1

* Sat Jan 05 2019 wally <wally> 0.32.3-5.mga7
+ Revision: 1349232
- disable bootstrap

* Fri Jan 04 2019 wally <wally> 0.32.3-4.mga7
+ Revision: 1349201
- another bootstrap build for python3.7

* Fri Jan 04 2019 wally <wally> 0.32.3-3.mga7
+ Revision: 1349200
- disable bootstrap

* Fri Jan 04 2019 wally <wally> 0.32.3-2.mga7
+ Revision: 1349179
- bootstrap build for python3.7

* Tue Jan 01 2019 wally <wally> 0.32.3-1.mga7
+ Revision: 1348255
- new version 0.32.3
- create python-wheel-wheel
- disable tests for now

* Mon Sep 24 2018 tv <tv> 0.30.0a0-4.mga7
+ Revision: 1303665
- really with python 3.6.6

* Fri Sep 21 2018 umeabot <umeabot> 0.30.0a0-3.mga7
+ Revision: 1290567
- Mageia 7 Mass Rebuild

* Thu Aug 03 2017 tv <tv> 0.30.0a0-2.mga7
+ Revision: 1134300
- rebuild for new python

* Sat Jul 29 2017 philippem <philippem> 0.30.0a0-1.mga7
+ Revision: 1132523
- change rel to 1
- update to 0.30.0a0, first step for python 3.6.2

* Fri Feb 19 2016 umeabot <umeabot> 0.26.0-2.mga6
+ Revision: 970441
- Mageia 6 Mass Rebuild

* Wed Sep 23 2015 philippem <philippem> 0.26.0-1.mga6
+ Revision: 882389
- update to 0.26.0

* Fri Aug 28 2015 philippem <philippem> 0.24.0-1.mga6
+ Revision: 870482
- update to 0.24.0

* Wed Oct 15 2014 umeabot <umeabot> 0.23.0-5.mga5
+ Revision: 743708
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.23.0-4.mga5
+ Revision: 730008
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 0.23.0-3.mga5
+ Revision: 688422
- Mageia 5 Mass Rebuild

* Sat May 31 2014 pterjan <pterjan> 0.23.0-2.mga5
+ Revision: 629102
- Rebuild for new Python

* Fri May 23 2014 philippem <philippem> 0.23.0-1.mga5
+ Revision: 625218
- update to 0.23, first step for Python 3.4

* Sun Apr 20 2014 philippem <philippem> 0.22.0-1.mga5
+ Revision: 617157
- add missing BR for tests
- imported package python-wheel

